@@ -6,10 +6,13 @@ from region_estimators.concentric_regions_estimator import ConcentricRegionsEsti
 from region_estimators.distance_simple_estimator import DistanceSimpleEstimator
 from region_estimators.region_estimator import RegionEstimator
 
+available_methods = {'concentric-regions': ConcentricRegionsEstimator,
+                    'distance-simple': DistanceSimpleEstimator}
 
 class RegionEstimatorFactory:
     factories = {}
 
+
     # A Template Method:
     @staticmethod
     def create(method_name, sites, regions, actuals, verbose=ConcentricRegionsEstimator.VERBOSE_DEFAULT,
@@ -23,12 +26,15 @@ class RegionEstimatorFactory:
 
     @staticmethod
     def get_classname(method_name):
-        if method_name == 'concentric-regions':
-            return 'ConcentricRegionsEstimator'
-        elif method_name == 'distance-simple':
-            return 'DistanceSimpleEstimator'
-        else:
-            raise ValueError('Method name does not exist')
+        try:
+            return available_methods[method_name].__name__
+        except:
+            raise ValueError('Method name {} does not exist. Available methods: \n{}'.format(method_name,
+                                                                                             available_methods.keys()))
+
+    @staticmethod
+    def get_available_methods():
+        return available_methods.keys()
 
 
 
